@@ -67,9 +67,9 @@ has "bip44_coin" => (
 
 sub register
 {
-	my ($self, $params) = @_;
+	my ($self, %config) = @_;
 	if (!blessed $self) {
-		$self = $self->new(%$params);
+		$self = $self->new(%config);
 	}
 	$networks{$self->id} = $self;
 	return $self;
@@ -117,7 +117,7 @@ sub get
 	return $network;
 }
 
-__PACKAGE__->register({
+__PACKAGE__->register(
 	id => "bitcoin",
 	name => "Bitcoin Mainnet",
 	p2pkh_byte => "\x00",
@@ -127,9 +127,9 @@ __PACKAGE__->register({
 	extprv_version => 0x0488ade4,
 	extpub_version => 0x0488b21e,
 	bip44_coin => 0,
-})->set_default;
+)->set_default;
 
-__PACKAGE__->register({
+__PACKAGE__->register(
 	id => "bitcoin_testnet",
 	name => "Bitcoin Testnet",
 	p2pkh_byte => "\x6f",
@@ -139,7 +139,7 @@ __PACKAGE__->register({
 	extprv_version => 0x04358394,
 	extpub_version => 0x043587cf,
 	bip44_coin => 1,
-});
+);
 
 1;
 
@@ -181,12 +181,12 @@ Bitcoin::Crypto::Network - Management tool for cryptocurrency networks
 
 	# register() can be used to create a network
 
-	my $litecoin = Bitcoin::Crypto::Network->register({
+	my $litecoin = Bitcoin::Crypto::Network->register(
 		id => "litecoin",
 		name => "Litecoin Mainnet",
 		p2pkh_byte => "\x30",
 		wif_byte => "\xb0",
-	});
+	);
 
 	# after you've added your network you can set it as default. This means that
 	# all extended keys generated by other means than importing serialized key and
@@ -206,7 +206,7 @@ you have to configure it's network first.
 
 Right now networks only require four keys, which are marked with *
 
-	my $config = {
+	my %config = (
 		id => "* identifier for the network",
 		name => "* human-readable network name",
 		p2pkh_byte => "* p2pkh address prefix byte, eg. 0x00",
@@ -216,7 +216,7 @@ Right now networks only require four keys, which are marked with *
 		extprv_version => "version of extended private keys, eg. 0x0488ade4",
 		extpub_version => "version of extended public keys, eg. 0x0488b21e",
 		bip44_coin => "bip44 coin number, eg. 0",
-	};
+	);
 
 After you register a network with this hashref your program will be able to import keys for that
 network but all keys created from other sources will be treated as Bitcoin.
@@ -233,11 +233,11 @@ with custom network without segwit_hrp field set.
 
 =head2 register
 
-	sig: register($self, $config = undef)
+	sig: register($self, %config)
 
-Calls Moose's new with keys present in $config hashref when called in static context.
+Calls Moose's new with keys present in $config hash when called in static context.
 Adds the newly created network instance or the one that the method was called on to a list of known networks.
-The second argument is ignored in object context.
+The hash %config is ignored in object context.
 
 =head2 set_default
 
@@ -248,6 +248,12 @@ keys will be bound to this network.
 
 =head1 STATIC METHODS
 
+=head2 new
+
+	sig: new($class, %config)
+
+Works the same as C<register> does in static context, but does not add the newly created network to a list of known networks.
+
 =head2 get
 
 	sig: get($class, $id = undef)
